@@ -1,5 +1,5 @@
 /*
- * Sylpheed -- a GTK+ based, lightweight, and fast e-mail client
+ * Claws Mail -- a GTK based, lightweight, and fast e-mail client
  * Copyright (C) 2001-2012 Match Grun and the Claws Mail team
  *
  * This program is free software; you can redistribute it and/or modify
@@ -21,6 +21,8 @@
  * Functions to maintain address cache.
  */
 
+#include "config.h"
+
 #include <stdio.h>
 #include <string.h>
 #include <sys/stat.h>
