@@ -21,8 +21,6 @@
 #include "claws-features.h"
 #endif
 
-/* This can probably be handled better, e.g. define it in config.h. */
-#define _WIN32_WINNT _WIN32_WINNT_WIN6
 #include <glib.h>
 #include <glib/gi18n.h>
 
