@@ -1,6 +1,6 @@
 /*
- * Claws Mail -- a GTK+ based, lightweight, and fast e-mail client
- * Copyright (C) 1999-2020 the Claws Mail team and Hiroyuki Yamamoto
+ * Claws Mail -- a GTK based, lightweight, and fast e-mail client
+ * Copyright (C) 1999-2022 the Claws Mail team and Hiroyuki Yamamoto
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -105,7 +105,7 @@ static gchar* edit_person_get_common_name_from_widgets(void)
 		}
 		if ( cn == NULL || *cn == '\0' ) {
 			g_free(cn);
-			cn = gtk_editable_get_chars( GTK_EDITABLE(personeditdlg.entry_nick), 0, -1 );;
+			cn = gtk_editable_get_chars( GTK_EDITABLE(personeditdlg.entry_nick), 0, -1 );
 		}
 	}
 #else
@@ -169,7 +169,7 @@ static void edit_person_ok(GtkWidget *widget, gboolean *cancelled) {
 				  "Click OK to keep editing this contact.\n"
 				  "Click Cancel to close without saving."),
 #endif
-				_("_Cancel"), _("_OK"), NULL, ALERTFOCUS_SECOND );
+				NULL, _("_Cancel"), NULL, _("_OK"), NULL, NULL, ALERTFOCUS_SECOND );
 		if( val == G_ALERTDEFAULT ) {
 			edit_person_cancel(widget, cancelled);
 		}
@@ -812,13 +812,13 @@ static GtkWidget* addressbook_edit_person_widgets_create( GtkWidget* container,
 
 	/* Button panel */
 	if (prefs_common.addressbook_use_editaddress_dialog)
-	gtkut_stock_button_set_create(&hbbox, &cancel_btn, _("_Cancel"),
-				      &ok_btn, _("_OK"),
-				      NULL, NULL);
+	gtkut_stock_button_set_create(&hbbox, &cancel_btn, NULL, _("_Cancel"),
+				      &ok_btn, NULL, _("_OK"),
+				      NULL, NULL, NULL);
 	else
 		gtkut_stock_with_text_button_set_create(&hbbox,
-					  &cancel_btn, _("_Cancel"), _("Discard"),
-				      &ok_btn, _("_OK"), _("Apply"),
+					  &cancel_btn, NULL, _("Discard"),
+				      &ok_btn, NULL, _("Apply"),
 				      NULL, NULL, NULL);
 	gtk_box_pack_end(GTK_BOX(vnbox), hbbox, FALSE, FALSE, 0);
 	gtk_widget_grab_default(ok_btn);
@@ -850,7 +850,7 @@ static void addressbook_edit_person_dialog_create( gboolean *cancelled ) {
 	/* gtk_container_set_border_width(GTK_CONTAINER(window), 0); */
 	gtk_window_set_title(GTK_WINDOW(window), _("Edit Person Data"));
 	gtk_window_set_position(GTK_WINDOW(window), GTK_WIN_POS_CENTER);
-	gtk_window_set_modal(GTK_WINDOW(window), FALSE);
+	gtk_window_set_modal(GTK_WINDOW(window), TRUE);
 	gtk_window_set_type_hint(GTK_WINDOW(window), GDK_WINDOW_TYPE_HINT_DIALOG);
 	g_signal_connect(G_OBJECT(window), "delete_event",
 			 G_CALLBACK(edit_person_delete_event),
@@ -877,7 +877,8 @@ static void addressbook_edit_person_dialog_create( gboolean *cancelled ) {
 
 	gtk_window_set_geometry_hints(GTK_WINDOW(window), NULL, &geometry,
 				      GDK_HINT_MIN_SIZE);
-	gtk_window_set_default_size(window, prefs_common.addressbookeditpersonwin_width,
+	gtk_window_set_default_size(GTK_WINDOW(window),
+				    prefs_common.addressbookeditpersonwin_width,
 				    prefs_common.addressbookeditpersonwin_height);
 
 	personeditdlg.container  = window;
@@ -1162,7 +1163,8 @@ static void edit_person_entry_email_changed (GtkWidget *entry, gpointer data)
 
 static gboolean edit_person_entry_email_pressed(GtkWidget *widget, GdkEventKey *event, gpointer data)
 {
-	if (event && event->keyval == GDK_KEY_Return) {
+	if (event && (event->keyval == GDK_KEY_KP_Enter ||
+	    event->keyval == GDK_KEY_Return)) {
 		if (email_saving)
 			edit_person_email_modify(NULL);		
 		else if (email_adding)
@@ -1318,11 +1320,11 @@ static void addressbook_edit_person_page_email( gint pageNum, gchar *pageLbl ) {
 	gtk_container_add( GTK_CONTAINER(vboxb), vbuttonbox );
 
 	/* Buttons */
-	buttonUp = gtkut_stock_button("go-up");
-	buttonDown = gtkut_stock_button("go-down");
-	buttonDel = gtkut_stock_button("edit-delete");
-	buttonMod = gtkut_stock_button("document-save");
-	buttonAdd = gtkut_stock_button("list-add");
+	buttonUp = gtkut_stock_button("go-up", _("_Up"));
+	buttonDown = gtkut_stock_button("go-down", _("_Down"));
+	buttonDel = gtkut_stock_button("edit-delete", _("D_elete"));
+	buttonMod = gtkut_stock_button("document-save", _("_Save"));
+	buttonAdd = gtkut_stock_button("list-add", _("_Add"));
 	
 
 #ifndef GENERIC_UMPC
@@ -1405,7 +1407,8 @@ static void edit_person_entry_att_changed (GtkWidget *entry, gpointer data)
 
 static gboolean edit_person_entry_att_pressed(GtkWidget *widget, GdkEventKey *event, gpointer data)
 {
-	if (event && event->keyval == GDK_KEY_Return) {
+	if (event && (event->keyval == GDK_KEY_KP_Enter ||
+	    event->keyval == GDK_KEY_Return)) {
 		if (attrib_saving)
 			edit_person_attrib_modify(NULL);
 		else if (attrib_adding)
@@ -1547,13 +1550,13 @@ static void addressbook_edit_person_page_attrib( gint pageNum, gchar *pageLbl )
 	gtk_container_add( GTK_CONTAINER(vboxb), vbuttonbox );
 
 	/* Buttons */
-	buttonDel = gtkut_stock_button("edit-delete");
+	buttonDel = gtkut_stock_button("edit-delete", _("D_elete"));
 	gtk_container_add( GTK_CONTAINER(vbuttonbox), buttonDel );
 
-	buttonMod = gtkut_stock_button("document-save");
+	buttonMod = gtkut_stock_button("document-save", _("_Save"));
 	gtk_container_add( GTK_CONTAINER(vbuttonbox), buttonMod );
 
-	buttonAdd = gtkut_stock_button("list-add");
+	buttonAdd = gtkut_stock_button("list-add", _("_Add"));
 	gtk_container_add( GTK_CONTAINER(vbuttonbox), buttonAdd );
 	
 	gtk_widget_set_sensitive(buttonDel,FALSE);
@@ -1710,12 +1713,12 @@ static gboolean addressbook_edit_person_close( gboolean cancelled )
 	listEMail = edit_person_build_email_list();
 	listAttrib = edit_person_build_attrib_list();
 	if( cancelled ) {
-		addritem_free_list_email( listEMail );
-		addritem_free_list_attribute( listAttrib );
 		model = gtk_tree_view_get_model(GTK_TREE_VIEW(personeditdlg.view_email));
 		gtk_list_store_clear(GTK_LIST_STORE(model));
 		model = gtk_tree_view_get_model(GTK_TREE_VIEW(personeditdlg.view_attrib));
 		gtk_list_store_clear(GTK_LIST_STORE(model));
+		addritem_free_list_email( listEMail );
+		addritem_free_list_attribute( listAttrib );
 
 		if (!prefs_common.addressbook_use_editaddress_dialog)
 			gtk_widget_hide( personeditdlg.container );
