@@ -1,5 +1,5 @@
 /*
- * Claws Mail -- a GTK+ based, lightweight, and fast e-mail client
+ * Claws Mail -- a GTK based, lightweight, and fast e-mail client
  * Copyright (C) 2001-2018 Hiroyuki Yamamoto & The Claws Mail Team
  *
  * This program is free software; you can redistribute it and/or modify
@@ -21,6 +21,7 @@
  * file is just that it make it easier to allow "user changeable" label colors.
  */
 
+#include "config.h"
 #include "defs.h"
 
 #include <glib.h>
