@@ -1,5 +1,5 @@
 /*
- * Claws Mail -- a GTK+ based, lightweight, and fast e-mail client
+ * Claws Mail -- a GTK based, lightweight, and fast e-mail client
  * Copyright (C) 1999-2020 the Claws Mail team and Hiroyuki Yamamoto
  *
  * This program is free software; you can redistribute it and/or modify
@@ -72,6 +72,7 @@ HeaderView *headerview_create(void)
 	headerview = g_new0(HeaderView, 1);
 
 	hbox = gtk_box_new(GTK_ORIENTATION_HORIZONTAL, 0);
+	gtk_widget_set_name(GTK_WIDGET(hbox), "headerview");
 	gtk_container_set_border_width(GTK_CONTAINER(hbox), 2);
 	vbox = gtk_box_new(GTK_ORIENTATION_VERTICAL, 2);
 	gtk_box_pack_start(GTK_BOX(hbox), vbox, TRUE, TRUE, 0);
@@ -277,7 +278,7 @@ static void headerview_save_contact_pic (HeaderView *headerview, MsgInfo *msginf
 	if (!is_file_exist(filename)) {
 		gdk_pixbuf_save(picture, filename, "png", &error, NULL);
 		if (error) {
-			g_warning("Failed to save image: %s",
+			g_warning("failed to save image: %s",
 					error->message);
 			g_error_free(error);
 		}
