@@ -4,7 +4,7 @@
  * Copyright (C) 2005-2019 Colin Leroy <colin@colino.net>
  * 	and the Claws Mail Team
  *
- * Sylpheed is a GTK+ based, lightweight, and fast e-mail client
+ * Sylpheed is a GTK based, lightweight, and fast e-mail client
  * Copyright (C) 1999-2019 Hiroyuki Yamamoto and the Claws Mail Team
  *
  * This program is free software; you can redistribute it and/or modify
@@ -32,7 +32,6 @@
 
 #include <string.h>
 
-#include <glib.h>
 #include <gtk/gtk.h>
 
 #include "defs.h"
@@ -623,7 +622,7 @@ static void acpi_prefs_save_func(PrefsPage * _page)
 
 	if (prefs_write_param(param, pfile->fp) < 0) {
 		g_warning("failed to write " PREFS_BLOCK_NAME 
-			  " configuration to file\n");
+			  " configuration to file");
 		prefs_file_close_revert(pfile);
 		return;
 	}
