@@ -41,10 +41,6 @@ extern "C" {
 const gchar *prefs_common_get_uri_cmd(void);
 }
 
-char master_css[] = {
-#include "css.inc"
-};
-
 static gboolean draw_cb(GtkWidget *widget, cairo_t *cr,
 		gpointer user_data);
 static gboolean button_press_event(GtkWidget *widget, GdkEventButton *event,
@@ -102,7 +98,6 @@ lh_widget::lh_widget()
 
 	m_html = NULL;
 	m_rendered_width = 0;
-	m_context.load_master_stylesheet(master_css);
 
 	m_font_name = NULL;
 	m_font_size = 0;
@@ -134,21 +129,25 @@ GtkWidget *lh_widget::get_widget() const
 	return m_scrolled_window;
 }
 
-void lh_widget::set_caption(const litehtml::tchar_t* caption)
+void lh_widget::set_caption(const char *caption)
 {
 	debug_print("lh_widget set_caption\n");
 	return;
 }
 
-void lh_widget::set_base_url(const litehtml::tchar_t* base_url)
+void lh_widget::set_base_url(const char *base_url)
 {
 	debug_print("lh_widget set_base_url '%s'\n",
 			(base_url ? base_url : "(null)"));
-	m_base_url = base_url;
+	if (base_url)
+		m_base_url = base_url;
+	else
+		m_base_url.clear();
+
 	return;
 }
 
-void lh_widget::on_anchor_click(const litehtml::tchar_t* url, const litehtml::element::ptr& el)
+void lh_widget::on_anchor_click(const char *url, const litehtml::element::ptr& el)
 {
 	debug_print("lh_widget on_anchor_click. url -> %s\n", url);
 
@@ -156,10 +155,9 @@ void lh_widget::on_anchor_click(const litehtml::tchar_t* url, const litehtml::el
 	return;
 }
 
-void lh_widget::import_css(litehtml::tstring& text, const litehtml::tstring& url, litehtml::tstring& baseurl)
+void lh_widget::import_css(litehtml::string& text, const litehtml::string& url, litehtml::string& baseurl)
 {
-	debug_print("lh_widget import_css\n");
-	baseurl = master_css;
+	debug_print("lh_widget import_css. url=\"%s\" baseurl=\"%s\"\n", url.c_str(), baseurl.c_str());
 }
 
 void lh_widget::get_client_rect(litehtml::position& client) const
@@ -186,7 +184,7 @@ void lh_widget::open_html(const gchar *contents)
 	update_font();
 
 	lh_widget_statusbar_push("Loading HTML part ...");
-	m_html = litehtml::document::createFromString(contents, this, &m_context);
+	m_html = litehtml::document::createFromString(contents, this);
 	m_rendered_width = 0;
 	if (m_html != NULL) {
 		debug_print("lh_widget::open_html created document\n");
@@ -306,9 +304,9 @@ void lh_widget::clear()
 	m_clicked_url.clear();
 }
 
-void lh_widget::set_cursor(const litehtml::tchar_t* cursor)
+void lh_widget::set_cursor(const char *cursor)
 {
-	litehtml::element::ptr over_el = m_html->over_element();
+	litehtml::element::const_ptr over_el = m_html->get_over_element();
 
 	if (m_showing_url &&
 			(over_el == NULL || over_el != m_over_element)) {
@@ -322,10 +320,10 @@ void lh_widget::set_cursor(const litehtml::tchar_t* cursor)
 	}
 }
 
-void lh_widget::update_cursor(const litehtml::tchar_t* cursor)
+void lh_widget::update_cursor(const char *cursor)
 {
 	GdkCursorType cursType = GDK_ARROW;
-	const litehtml::tchar_t *href = get_href_at(m_over_element);
+	const char *href = get_href_at(m_over_element);
 
 	/* If there is a href, and litehtml is okay with showing a pointer
 	 * cursor ("pointer" or "auto"), set it, otherwise keep the
@@ -350,9 +348,9 @@ void lh_widget::update_cursor(const litehtml::tchar_t* cursor)
 	}
 }
 
-const litehtml::tchar_t *lh_widget::get_href_at(litehtml::element::ptr element) const
+const char *lh_widget::get_href_at(litehtml::element::const_ptr element)
 {
-	litehtml::element::ptr el;
+	litehtml::element::const_ptr el;
 
 	if (element == NULL)
 		return NULL;
@@ -374,21 +372,7 @@ const litehtml::tchar_t *lh_widget::get_href_at(litehtml::element::ptr element)
 
 	/* At this point, over_el is pointing at an anchor tag, so let's
 	 * grab its href attribute. */
-	return el->get_attr(_t("href"));
-}
-
-const litehtml::tchar_t *lh_widget::get_href_at(const gint x, const gint y) const
-{
-	litehtml::element::ptr over_el, el;
-
-	if (m_html == NULL)
-		return NULL;
-
-	over_el = m_html->root()->get_element_by_point(x, y, x, y);
-	if (over_el == NULL)
-		return NULL;
-
-	return get_href_at(over_el);
+	return el->get_attr("href");
 }
 
 void lh_widget::print()
@@ -397,7 +381,7 @@ void lh_widget::print()
     gtk_widget_realize(GTK_WIDGET(m_drawing_area));
 }
 
-void lh_widget::popup_context_menu(const litehtml::tchar_t *url,
+void lh_widget::popup_context_menu(const char *url,
 		GdkEventButton *event)
 {
 	cm_return_if_fail(url != NULL);
@@ -428,12 +412,12 @@ void lh_widget::update_font()
 	debug_print("Font set to '%s', size %d\n", m_font_name, m_font_size);
 }
 
-const litehtml::tstring lh_widget::fullurl(const litehtml::tchar_t *url) const
+const litehtml::string lh_widget::fullurl(const char *url) const
 {
 	if (*url == '#' && !m_base_url.empty())
 		return m_base_url + url;
 
-	return _t(url);
+	return url;
 }
 
 void lh_widget::set_partinfo(MimeInfo *partinfo)
@@ -441,7 +425,7 @@ void lh_widget::set_partinfo(MimeInfo *partinfo)
 	m_partinfo = partinfo;
 }
 
-GdkPixbuf *lh_widget::get_local_image(const litehtml::tstring url) const
+GdkPixbuf *lh_widget::get_local_image(const litehtml::string url) const
 {
 	GdkPixbuf *pixbuf;
 	const gchar *name;
@@ -514,7 +498,7 @@ static gboolean button_press_event(GtkWidget *widget, GdkEventButton *event,
 
 	/* Right-click */
 	if (event->button == 3) {
-		const litehtml::tchar_t *url = w->get_href_at((gint)event->x, (gint)event->y);
+		const char *url = w->get_href_at(w->m_html->get_over_element());
 
 		if (url != NULL)
 			w->popup_context_menu(url, event);
