@@ -38,6 +38,9 @@
 #ifdef HAVE_LIBCANBERRA_GTK
 # include <canberra-gtk.h>
 #endif
+#ifdef NOTIFICATION_AYATANA_INDICATOR
+# include "notification_ayatana_indicator.h"
+#endif
 
 typedef struct {
   GSList *collected_msgs;
@@ -125,6 +128,9 @@ void notification_update_msg_counts(FolderItem *removed_item)
 #ifdef NOTIFICATION_TRAYICON
   notification_update_trayicon();
 #endif
+#ifdef NOTIFICATION_AYATANA_INDICATOR
+  notification_update_ayatana_indicator();
+#endif
 #ifdef NOTIFICATION_INDICATOR
   notification_update_indicator();
 #endif
