@@ -275,7 +275,7 @@ GPtrArray *procheader_get_header_array(FILE *fp)
 
 	headers = g_ptr_array_new();
 
-	while (procheader_get_one_field_asis(&buf, fp) != -1) {
+	while (procheader_get_one_field(&buf, fp, NULL) != -1) {
 		if ((header = procheader_parse_header(buf)) != NULL)
 			g_ptr_array_add(headers, header);
 		g_free(buf);
@@ -1357,7 +1357,7 @@ gboolean procheader_header_is_internal(const gchar *hdr_name)
 	const gchar *internal_hdrs[] = {
 		"AF:", "NF:", "PS:", "SRH:", "SFN:", "DSR:", "MID:", "CFG:",
 		"PT:", "S:", "RQ:", "SSV:", "NSV:", "SSH:", "R:", "MAID:",
-		"SCF:", "RMID:", "FMID:", "NAID:",
+		"SCF:", "RRCPT:", "RMID:", "FMID:", "NAID:",
 		"X-Claws-Account-Id:",
 		"X-Claws-Sign:",
 		"X-Claws-Encrypt:",
