@@ -1,7 +1,6 @@
 /*
- * Claws Mail -- a GTK+ based, lightweight, and fast e-mail client
- * Copyright (C) 1999-2019 Colin Leroy <colin@colino.net>
- * and the Claws Mail team
+ * Claws Mail -- a GTK based, lightweight, and fast e-mail client
+ * Copyright (C) 1999-2022 the Claws Mail team and Colin Leroy
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -168,8 +167,8 @@ static PrefParam template_params[] = {
 	 &tmpl.smtpuser, P_STRING, NULL, NULL, NULL},
 	{"smtppass", "",
 	 &tmpl.smtppass, P_STRING, NULL, NULL, NULL},
-	{"recvtype", A_POP3,
-	 &tmpl.recvtype, P_INT, NULL, NULL, NULL},
+	{"recvtype", "0",
+	 &tmpl.recvtype, P_ENUM, NULL, NULL, NULL},
 	{"recvserver", "pop.$DOMAIN",
 	 &tmpl.recvserver, P_STRING, NULL, NULL, NULL},
 	{"recvuser", "$LOGIN",
@@ -239,7 +238,7 @@ static gchar *accountrc_tmpl =
 	"\n"
 	"#recvtype can be:\n"
 	"#0 for pop3\n"
-	"#2  for imap\n"
+	"#1  for imap\n"
 	"#3  for a local mbox file\n"
 	"#recvtype=\n"
 	"\n"
@@ -273,26 +272,26 @@ static gchar *accountrc_tmpl =
 	"#mailbox=\n"
 	"\n"
 	"#whether to use encryption on SMTP connections\n"
-	"#default is 0, 1 is SSL/TLS, 2 is STARTTLS\n"
+	"#default is 0, 1 is TLS, 2 is STARTTLS\n"
 	"#smtpssl=\n"
 	"\n"
 	"#whether to use encryption on POP3 or IMAP connections\n"
-	"#default is 0, 1 is SSL/TLS, 2 is STARTTLS\n"
+	"#default is 0, 1 is TLS, 2 is STARTTLS\n"
 	"#recvssl=\n"
 	"\n"
-	"#SSL/TLS client certificate path for SMTP\n"
+	"#TLS client certificate path for SMTP\n"
 	"#default is empty (no certificate)\n"
 	"#smtpssl_cert=\n"
 	"\n"
-	"#SSL/TLS client certificate path for POP/IMAP\n"
+	"#TLS client certificate path for POP/IMAP\n"
 	"#default is empty (no certificate)\n"
 	"#recvssl_cert=\n"
 	"\n"
-	"#SSL/TLS client certificate password for SMTP\n"
+	"#TLS client certificate password for SMTP\n"
 	"#default is empty (no password)\n"
 	"#smtpssl_cert_pass=\n"
 	"\n"
-	"#SSL/TLS client certificate password for POP/IMAP\n"
+	"#TLS client certificate password for POP/IMAP\n"
 	"#default is empty (no password)\n"
 	"#recvssl_cert_pass=\n"
 	;
@@ -538,7 +537,7 @@ static void write_welcome_email(WizardWindow *wizard)
 		"Face: %s\n"
 		"Content-Type: text/plain; charset=UTF-8\n",
 		enc_from_name,
-		USERS_ML_ADDR,
+		WELCOME_MSG_ADDR,
 		enc_to_name,
 		gtk_entry_get_text(GTK_ENTRY(wizard->email)),
 		date, enc_subject, XFACE, FACE);
@@ -849,7 +848,7 @@ static GtkWidget* create_page (WizardWindow *wizard, const char * title)
 
 	/* create the titlebar */
 	hbox = gtk_box_new(GTK_ORIENTATION_HORIZONTAL, 12);
-	image = stock_pixmap_widget(STOCK_PIXMAP_CLAWS_MAIL_ICON);
+	image = priv_pixmap_widget(PRIV_PIXMAP_CLAWS_MAIL_ICON);
 	gtk_box_pack_start (GTK_BOX(hbox), image, FALSE, FALSE, 0);
      	title_string = g_strconcat ("<span size=\"xx-large\" weight=\"ultrabold\">", title ? title : "", "</span>", NULL);
 	w = gtk_label_new (title_string);
@@ -863,11 +862,6 @@ static GtkWidget* create_page (WizardWindow *wizard, const char * title)
 	/* pack the separator */
 	gtk_box_pack_start (GTK_BOX(vbox), gtk_separator_new(GTK_ORIENTATION_HORIZONTAL), FALSE, FALSE, 0);
 
-	/* pack space */
-	w = gtk_alignment_new (0, 0, 0, 0);
-	gtk_widget_set_size_request (w, 0, 6);
-	gtk_box_pack_start (GTK_BOX(vbox), w, FALSE, FALSE, 0);
-
 	return vbox;
 }
 
@@ -982,6 +976,7 @@ static GtkWidget* user_page (WizardWindow * wizard)
 	gtk_grid_attach(GTK_GRID(user_table), wizard->full_name, 1, 0, 1, 1);
 	gtk_widget_set_hexpand(wizard->full_name, TRUE);
 	gtk_widget_set_halign(wizard->full_name, GTK_ALIGN_FILL);
+	gtk_widget_set_margin_start(wizard->full_name, 4);
 
 	label = gtk_label_new(g_strconcat("<span weight=\"bold\">", _("Your email address:"),
 					  "</span>", NULL));
@@ -994,6 +989,7 @@ static GtkWidget* user_page (WizardWindow * wizard)
 	gtk_grid_attach(GTK_GRID(user_table), wizard->email, 1, 1, 1, 1);
 	gtk_widget_set_hexpand(wizard->email, TRUE);
 	gtk_widget_set_halign(wizard->email, GTK_ALIGN_FILL);
+	gtk_widget_set_margin_start(wizard->email, 4);
 
 	label = gtk_label_new(_("Your organization:"));
 	gtk_label_set_xalign(GTK_LABEL(label), 1.0);
@@ -1004,6 +1000,7 @@ static GtkWidget* user_page (WizardWindow * wizard)
 	gtk_grid_attach(GTK_GRID(user_table), wizard->organization, 1, 2, 1, 1);
 	gtk_widget_set_hexpand(wizard->organization, TRUE);
 	gtk_widget_set_halign(wizard->organization, GTK_ALIGN_FILL);
+	gtk_widget_set_margin_start(wizard->organization, 4);
 	
 	g_signal_connect(G_OBJECT(wizard->email), "changed",
 			 G_CALLBACK(wizard_email_changed),
@@ -1068,7 +1065,7 @@ static void cert_browse_cb(GtkWidget *widget, gpointer data)
 
 	utf8_filename = g_filename_to_utf8(filename, -1, NULL, NULL, NULL);
 	if (!utf8_filename) {
-		g_warning("cert_browse_cb(): failed to convert character set.");
+		g_warning("cert_browse_cb(): failed to convert character set");
 		utf8_filename = g_strdup(filename);
 	}
 	gtk_entry_set_text(dest, utf8_filename);
@@ -1148,6 +1145,8 @@ static GtkWidget* smtp_page (WizardWindow * wizard)
 	gtk_entry_set_text(GTK_ENTRY(wizard->smtp_username), text);
 	g_free(text);
 	gtk_grid_attach(GTK_GRID(smtp_auth_table), wizard->smtp_username, 1, 0, 1, 1);
+	gtk_widget_set_margin_start(wizard->smtp_username, 4);
+	gtk_widget_set_margin_bottom(wizard->smtp_username, 4);
 	gtk_widget_set_hexpand(wizard->smtp_username, TRUE);
 	gtk_widget_set_halign(wizard->smtp_username, GTK_ALIGN_FILL);
 
@@ -1161,12 +1160,13 @@ static GtkWidget* smtp_page (WizardWindow * wizard)
 	gtk_grid_attach(GTK_GRID(smtp_auth_table), wizard->smtp_password, 1, 1, 1, 1);
 	gtk_widget_set_hexpand(wizard->smtp_password, TRUE);
 	gtk_widget_set_halign(wizard->smtp_password, GTK_ALIGN_FILL);
+	gtk_widget_set_margin_start(wizard->smtp_password, 4);
 
 #ifdef USE_GNUTLS
 	hbox = gtk_box_new(GTK_ORIENTATION_HORIZONTAL, VSPACING_NARROW);
 	gtk_box_pack_start (GTK_BOX(vbox), hbox, FALSE, FALSE, 0);
 	wizard->smtp_use_ssl = gtk_check_button_new_with_label(
-					_("Use SSL/TLS to connect to SMTP server"));
+					_("Use TLS to connect to SMTP server"));
 	gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(wizard->smtp_use_ssl),
 			tmpl.smtpssl != 0);
 	gtk_box_pack_start(GTK_BOX(hbox), wizard->smtp_use_ssl, FALSE, FALSE, 0);
@@ -1189,7 +1189,7 @@ static GtkWidget* smtp_page (WizardWindow * wizard)
 	hbox_spc = gtk_box_new(GTK_ORIENTATION_HORIZONTAL, 0);
 	gtk_widget_set_size_request (hbox_spc, 12, -1);
 	gtk_box_pack_start (GTK_BOX (hbox), hbox_spc, FALSE, FALSE, 0);
-	label = gtk_label_new(_("Client SSL/TLS certificate (optional)"));
+	label = gtk_label_new(_("Client TLS certificate (optional)"));
 	gtk_label_set_xalign(GTK_LABEL(label), 0.0);
 	gtk_box_pack_start (GTK_BOX (hbox), label, FALSE, FALSE, 0);
 	gtk_grid_attach(GTK_GRID(smtp_cert_table), hbox, 0, 0, 1, 1);
@@ -1198,8 +1198,10 @@ static GtkWidget* smtp_page (WizardWindow * wizard)
 	hbox_spc = gtk_box_new(GTK_ORIENTATION_HORIZONTAL, 0);
 	gtk_widget_set_size_request (hbox_spc, 12, -1);
 	gtk_box_pack_start (GTK_BOX (hbox), hbox_spc, FALSE, FALSE, 0);
-	label = gtk_label_new(_("File"));
+	label = gtk_label_new(_("File:"));
 	gtk_label_set_xalign(GTK_LABEL(label), 1.0);
+	gtk_widget_set_margin_start(label, 4);
+	gtk_widget_set_margin_bottom(label, 4);
 	gtk_box_pack_start (GTK_BOX (hbox), label, TRUE, TRUE, 0);
 	gtk_grid_attach(GTK_GRID(smtp_cert_table), hbox, 0, 1, 1, 1);
 
@@ -1208,6 +1210,9 @@ static GtkWidget* smtp_page (WizardWindow * wizard)
 	gtk_grid_attach(GTK_GRID(smtp_cert_table), wizard->smtp_ssl_cert_file, 1, 1, 1, 1);
 	gtk_widget_set_hexpand(wizard->smtp_ssl_cert_file, TRUE);
 	gtk_widget_set_halign(wizard->smtp_ssl_cert_file, GTK_ALIGN_FILL);
+	gtk_widget_set_margin_start(wizard->smtp_ssl_cert_file, 4);
+	gtk_widget_set_margin_end(wizard->smtp_ssl_cert_file, 4);
+	gtk_widget_set_margin_bottom(wizard->smtp_ssl_cert_file, 4);
 
 	button = gtkut_get_browse_file_btn(_("Browse"));
 	gtk_grid_attach(GTK_GRID(smtp_cert_table), button, 2, 1, 1, 1);
@@ -1219,8 +1224,9 @@ static GtkWidget* smtp_page (WizardWindow * wizard)
 	hbox_spc = gtk_box_new(GTK_ORIENTATION_HORIZONTAL, 0);
 	gtk_widget_set_size_request (hbox_spc, 12, -1);
 	gtk_box_pack_start (GTK_BOX (hbox), hbox_spc, FALSE, FALSE, 0);	
-	label = gtk_label_new(_("Password"));
+	label = gtk_label_new(_("Password:"));
 	gtk_label_set_xalign(GTK_LABEL(label), 1.0);
+	gtk_widget_set_margin_start(label, 4);
 	gtk_box_pack_start (GTK_BOX (hbox), label, TRUE, TRUE, 0);
 	gtk_grid_attach(GTK_GRID(smtp_cert_table), hbox, 0, 2, 1, 1);
 
@@ -1230,6 +1236,7 @@ static GtkWidget* smtp_page (WizardWindow * wizard)
 	gtk_grid_attach(GTK_GRID(smtp_cert_table), wizard->smtp_ssl_cert_pass, 1, 2, 1, 1);
 	gtk_widget_set_hexpand(wizard->smtp_ssl_cert_pass, TRUE);
 	gtk_widget_set_halign(wizard->smtp_ssl_cert_pass, GTK_ALIGN_FILL);
+	gtk_widget_set_margin_start(wizard->smtp_ssl_cert_pass, 4);
 
 	SET_TOGGLE_SENSITIVITY (wizard->smtp_use_ssl, smtp_cert_table);
 	wizard->smtp_cert_table = smtp_cert_table;
@@ -1523,6 +1530,7 @@ static GtkWidget* recv_page (WizardWindow * wizard)
 		index = 0;
 	}
 	gtk_combo_box_set_active(GTK_COMBO_BOX (wizard->recv_type), index);
+	gtk_widget_set_margin_start(wizard->recv_type, 4);
 	g_signal_connect(G_OBJECT(wizard->recv_type), "changed",
 			 G_CALLBACK(wizard_protocol_changed),
 			 wizard);
@@ -1557,6 +1565,8 @@ static GtkWidget* recv_page (WizardWindow * wizard)
 	wizard->recv_server = gtk_entry_new();
 	text = get_default_server(wizard, "pop");
 	gtk_entry_set_text(GTK_ENTRY(wizard->recv_server), text);
+	gtk_widget_set_margin_start(wizard->recv_server, 4);
+	gtk_widget_set_margin_bottom(wizard->recv_server, 4);
 	g_free(text);
 	
 	CLAWS_SET_TIP(wizard->recv_server,
@@ -1579,6 +1589,8 @@ static GtkWidget* recv_page (WizardWindow * wizard)
 	gtk_grid_attach(GTK_GRID(recv_table), wizard->recv_username, 1, 3, 1, 1);
 	gtk_widget_set_hexpand(wizard->recv_username, TRUE);
 	gtk_widget_set_halign(wizard->recv_username, GTK_ALIGN_FILL);
+	gtk_widget_set_margin_start(wizard->recv_username, 4);
+	gtk_widget_set_margin_bottom(wizard->recv_username, 4);
 			 
 	wizard->recv_password_label = gtk_label_new(_("Password:"));
 	gtk_label_set_xalign(GTK_LABEL(wizard->recv_password_label), 1.0);
@@ -1590,12 +1602,14 @@ static GtkWidget* recv_page (WizardWindow * wizard)
 	gtk_grid_attach(GTK_GRID(recv_table), wizard->recv_password, 1, 4, 1, 1);
 	gtk_widget_set_hexpand(wizard->recv_password, TRUE);
 	gtk_widget_set_halign(wizard->recv_password, GTK_ALIGN_FILL);
+	gtk_widget_set_margin_start(wizard->recv_password, 4);
+
 
 #ifdef USE_GNUTLS
 	hbox = gtk_box_new(GTK_ORIENTATION_HORIZONTAL, VSPACING_NARROW);
 	gtk_box_pack_start (GTK_BOX(vbox), hbox, FALSE, FALSE, 0);
 	wizard->recv_use_ssl = gtk_check_button_new_with_label(
-					_("Use SSL/TLS to connect to receiving server"));
+					_("Use TLS to connect to receiving server"));
 	gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(wizard->recv_use_ssl),
 			tmpl.recvssl != 0);
 	gtk_box_pack_start(GTK_BOX(hbox), wizard->recv_use_ssl, FALSE, FALSE, 0);
@@ -1619,7 +1633,7 @@ static GtkWidget* recv_page (WizardWindow * wizard)
 	hbox_spc = gtk_box_new(GTK_ORIENTATION_HORIZONTAL, 0);
 	gtk_widget_set_size_request (hbox_spc, 12, -1);
 	gtk_box_pack_start (GTK_BOX (hbox), hbox_spc, FALSE, FALSE, 0);
-	label = gtk_label_new(_("Client SSL/TLS certificate (optional)"));
+	label = gtk_label_new(_("Client TLS certificate (optional)"));
 	gtk_label_set_xalign(GTK_LABEL(label), 0.0);
 	gtk_box_pack_start (GTK_BOX (hbox), label, FALSE, FALSE, 0);	
 	gtk_grid_attach(GTK_GRID(recv_cert_table), hbox, 0, 0, 1, 1);
@@ -1629,7 +1643,7 @@ static GtkWidget* recv_page (WizardWindow * wizard)
 	gtk_widget_set_size_request (hbox_spc, 12, -1);
 	gtk_box_pack_start (GTK_BOX (hbox), hbox_spc, FALSE, FALSE, 0);
 
-	label = gtk_label_new(_("File"));
+	label = gtk_label_new(_("File:"));
 	gtk_label_set_xalign(GTK_LABEL(label), 1.0);
 	gtk_box_pack_start (GTK_BOX (hbox), label, TRUE, TRUE, 0);	
 	gtk_grid_attach(GTK_GRID(recv_cert_table), hbox, 0, 1, 1, 1);
@@ -1638,6 +1652,9 @@ static GtkWidget* recv_page (WizardWindow * wizard)
 	gtk_grid_attach(GTK_GRID(recv_cert_table), wizard->recv_ssl_cert_file, 1, 1, 1, 1);
 	gtk_widget_set_hexpand(wizard->recv_ssl_cert_file, TRUE);
 	gtk_widget_set_halign(wizard->recv_ssl_cert_file, GTK_ALIGN_FILL);
+	gtk_widget_set_margin_start(wizard->recv_ssl_cert_file, 4);
+	gtk_widget_set_margin_end(wizard->recv_ssl_cert_file, 4);
+	gtk_widget_set_margin_bottom(wizard->recv_ssl_cert_file, 4);
 
 	button = gtkut_get_browse_file_btn(_("Browse"));
 	gtk_grid_attach(GTK_GRID(recv_cert_table), button, 2, 1, 1, 1);
@@ -1649,7 +1666,7 @@ static GtkWidget* recv_page (WizardWindow * wizard)
 	hbox_spc = gtk_box_new(GTK_ORIENTATION_HORIZONTAL, 0);
 	gtk_widget_set_size_request (hbox_spc, 12, -1);
 	gtk_box_pack_start (GTK_BOX (hbox), hbox_spc, FALSE, FALSE, 0);
-	label = gtk_label_new(_("Password"));
+	label = gtk_label_new(_("Password:"));
 	gtk_label_set_xalign(GTK_LABEL(label), 1.0);
 	gtk_box_pack_start (GTK_BOX (hbox), label, TRUE, TRUE, 0);
 	gtk_grid_attach(GTK_GRID(recv_cert_table), hbox, 0, 2, 1, 1);
@@ -1660,6 +1677,8 @@ static GtkWidget* recv_page (WizardWindow * wizard)
 	gtk_grid_attach(GTK_GRID(recv_cert_table), wizard->recv_ssl_cert_pass, 1, 2, 1, 1);
 	gtk_widget_set_hexpand(wizard->recv_ssl_cert_pass, TRUE);
 	gtk_widget_set_halign(wizard->recv_ssl_cert_pass, GTK_ALIGN_FILL);
+	gtk_widget_set_margin_start(wizard->recv_ssl_cert_pass, 4);
+	gtk_widget_set_margin_bottom(wizard->recv_ssl_cert_pass, 4);
 
 	SET_TOGGLE_SENSITIVITY (wizard->recv_use_ssl, recv_cert_table);	
 	wizard->recv_cert_table = recv_cert_table;
@@ -1814,7 +1833,7 @@ gboolean run_wizard(MainWindow *mainwin, gboolean create_mailbox) {
 			_("_Cancel"), CANCEL,
 			NULL);
 	gtk_window_set_position(GTK_WINDOW(wizard->window), GTK_WIN_POS_CENTER);
-	gtk_window_set_default_size(GTK_WINDOW(wizard->window), 390, 420);
+	gtk_window_set_default_size(GTK_WINDOW(wizard->window), 550, 500);
 
 	g_signal_connect(wizard->window, "response", 
 			  G_CALLBACK(wizard_response_cb), wizard);
@@ -1843,7 +1862,7 @@ gboolean run_wizard(MainWindow *mainwin, gboolean create_mailbox) {
 	page = create_page(wizard, _("Welcome to Claws Mail"));
 	
 	wizard->pages = g_slist_append(wizard->pages, page);
-	widget = stock_pixmap_widget(STOCK_PIXMAP_CLAWS_MAIL_LOGO);
+	widget = priv_pixmap_widget(PRIV_PIXMAP_CLAWS_MAIL_LOGO);
 
 	gtk_box_pack_start (GTK_BOX(page), widget, FALSE, FALSE, 0);
 	
@@ -1921,7 +1940,7 @@ gboolean run_wizard(MainWindow *mainwin, gboolean create_mailbox) {
 	page = create_page(wizard, _("Configuration finished"));
 	
 	wizard->pages = g_slist_append(wizard->pages, page);
-	widget = stock_pixmap_widget(STOCK_PIXMAP_CLAWS_MAIL_LOGO);
+	widget = priv_pixmap_widget(PRIV_PIXMAP_CLAWS_MAIL_LOGO);
 
 	gtk_box_pack_start (GTK_BOX(page), widget, FALSE, FALSE, 0);
 	
